/* Copyright (c) 2010 Marcin Zajaczkowski
 * All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.appinfo.formatter;

/**
 * Interface for class formating application info into specific format ready for end use.
 *
 * @author Marcin Zajączkowski, 2010-07-01
 */
public interface ApplicationInfoFormatter {

    /**
     * Returns application info in format which is able to direct use application.
     *
     * Subclasses should determine specific format (e.g. for title bar or web footer)
     *
     * @return application info in desired format
     */
    public String getInfo();

    /**
     * Prints application info in format given by getInfo() to the log.
     *
     * Could be used after formatter bean creation (in PostConstruct/init) to print application version to the log.
     */
    public void printInfo();
}
