/* Copyright (c) 2010 Marcin Zajaczkowski
 * All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.appinfo.formatter;

import net.sf.appinfo.ApplicationInfo;
import org.springframework.util.Assert;

/**
 * Basic implementation of class formating application info to desired format.
 *
 * @author Marcin Zajączkowski, 2010-07-01
 */
public class BasicApplicationInfoFormatter extends AbstractApplicationInfoFormatter {

    //Package access level for usage in tests
    static final String SEPARATOR = " - ";
    static final String BUILD_TEXT = "Build ";

    private final ApplicationInfo applicationInfo;

    public BasicApplicationInfoFormatter(ApplicationInfo applicationInfo) {
        super();
        Assert.notNull(applicationInfo, "applicationInfo cannot be null");
        this.applicationInfo = applicationInfo;
    }

    /** {@inheritDoc} */
    public String getInfo() {
        StringBuilder sb = new StringBuilder();
        sb.append(applicationInfo.getName());
        sb.append(SEPARATOR);
        sb.append(applicationInfo.getVersion());
        sb.append(SEPARATOR);
        sb.append(BUILD_TEXT);
        sb.append(applicationInfo.getBuildNumber());
        sb.append(SEPARATOR);
        sb.append(applicationInfo.getBuildDate());
        return sb.toString();
    }
}

