/* Copyright (c) 2010 Marcin Zajaczkowski
 * All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.appinfo.formatter;

import org.springframework.util.Assert;

/**
 * ApplicationInfo formatter with caching abilities.
 *
 * Designed to be used as a wrapper/decorator of the other ApplicationInfoFormatter implementations providing
 * cached read of values. Wrapped formatter is used in the first request, later value is returned from local cache.
 *
 * When using Spring appInfoText bean could be a good alternative.
 *
 * @since 0.5.0
 *
 * @author Marcin Zajączkowski, 2010-10-16
 */
public class CachingApplicationInfoFormatter implements ApplicationInfoFormatter {

    private String cachedInfo = null;
    private ApplicationInfoFormatter appInfoFormatter;

    public CachingApplicationInfoFormatter(ApplicationInfoFormatter appInfoFormatter) {
        Assert.notNull(appInfoFormatter, "appInfoFormatter cannot be null");
        this.appInfoFormatter = appInfoFormatter;
    }

    //TODO: MZA: Has to be synchronized?
    public synchronized String getInfo() {
        if (cachedInfo == null) {
            cachedInfo = appInfoFormatter.getInfo();
        }
        return cachedInfo;
    }

    public void printInfo() {
        appInfoFormatter.printInfo();
    }
}
