/* Copyright (c) 2010 Marcin Zajaczkowski
 * All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.appinfo.reader;

import java.io.IOException;
import java.net.URL;
import java.util.jar.Manifest;

/**
 * Klasa odczytująca dane z pliku manifestu znajdującego się w JARze, w którym znajduje się wskazana klasa.
 *
 * @author Marcin Zajączkowski, 2010-07-01
 */
public class JarManifestReader implements ManifestReader {

    private final Class<?> classFromJar;
    private Manifest manifest;

    /**
     * Wykorzystuje siebie (this) jako klasę, w JARze której będzie szukany plik manifestu.
     */
    public JarManifestReader() {
        this.classFromJar = getClass();
    }

    /**
     * Wykorzystuje przekazaną klasę, jako klasę, w JARze której będzie szukany plik manifestu.
     *
     * @param classFromJar klasa z JARa
     */
    public JarManifestReader(Class<?> classFromJar) {
        this.classFromJar = classFromJar;
    }

    /** {@inheritDoc} */
    public synchronized Manifest getManifest() throws IOException {
        if (manifest == null) {
            manifest = getManifestByClass(classFromJar);
        }
        return manifest;
    }

    private Manifest getManifestByClass(Class<?> classFromRightJar) throws IOException {
        //Based on: http://forums.sun.com/thread.jspa?messageID=10061355#10061355
        String classContainer = classFromRightJar.getProtectionDomain().getCodeSource().getLocation().toString();
        URL manifestUrl = new URL("jar:" + classContainer + "!/META-INF/MANIFEST.MF");
        return new Manifest(manifestUrl.openStream());
    }
}
